.. currentmodule:: disnake_compass.impl

Parser Base Implementation
==========================

.. automodule:: disnake_compass.impl.parser.base


Functions
---------

.. autofunction:: get_parser

.. autofunction:: register_parser


Classes
-------

.. attributetable:: disnake_compass.impl.parser.base.Parser

.. autoclass:: disnake_compass.impl.parser.base.Parser
    :members: default, default_types, dumps, loads
